==> nextcloud-26.0.10.tgz: nextcloud/apps/privacy/l10n/ca.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privadesa",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "El centre de privadesa us mostra on s'emmagatzemen les vostres dades i qui pot accedir-hi, ja sigui perquè les vau compartir o perquè són usuaris administradors.",
    "Administrators" : "Administradors",
    "Remove external {propertyName} admin" : "Elimina l'administrador extern {propertyName}",
    "Add external admin" : "Afegeix un administrador extern",
    "Cancel" : "Cancelar",
    "Add" : "Afegeix",
    "Name of external admin" : "Nom de l'administrador extern",
    "Encryption" : "Xifratge",
    "Edit" : "Edició",
    "This server is using full-disk-encryption." : "Aquest servidor utilitza xifratge complet de disc.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "L'emmagatzematge de casa s'encripta mitjançant el {linkopen}xifratge del costat del servidor ↗{linkclose} amb una clau mestra. Significa que els administradors poden accedir als vostres fitxers, però no llegir-ne el contingut.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Els fitxers en ubicacions d'emmagatzematge extern poden estar xifrats mitjançant {linkopen}xifratge del servidor ↗{linkclose} amb una clau mestra en funció de la configuració.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "L'emmagatzematge de casa s'encripta mitjançant el {linkopen}xifratge del costat del servidor ↗{linkclose} amb una clau d'usuari individual. Significa que els administradors poden accedir als vostres fitxers, però no llegir-ne el contingut.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Els fitxers en ubicacions d'emmagatzematge extern poden estar xifrats mitjançant {linkopen}xifratge del servidor ↗{linkclose} amb una clau individual en funció de la configuració.",
    "Additionally, this server is protected with full-disk-encryption." : "A més, aquest servidor està protegit mitjançant xifratge complet del disc.",
    "This server is protected with full-disk-encryption." : "Aquest servidor està protegit mitjançant xifratge complet del disc.",
    "Your files are not protected by encryption." : "Els vostres fitxers no estan protegits per xifratge.",
    "Privacy policy" : "Política de privadesa",
    "Who has access to your data?" : "Qui té accés a les vostres dades?",
    "Where is your data?" : "On són les vostres dades?",
    "Your data is located in:" : "Les vostres dades es troben a:",
    "Change data location" : "Canvia la ubicació de les dades",
    "Region" : "Regió",
    "Please select a region" : "Seleccioneu una regió",
    "User Data Manifesto 2.0" : "Manifest de dades de l'usuari 2.0",
    "Control" : "Control",
    "over user data access" : "sobre l’accés a les dades dels usuaris",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Les dades pujades de manera explícita i voluntària per part d'un usuari han d'estar sota el control definitiu de l'usuari. Els usuaris han de poder decidir a qui concedeixen accés directe a les seves dades i amb quins permisos i llicències es concedeix l'accés.",
    "Knowledge" : "Coneixement",
    "of how the data is stored" : "de com s'emmagatzemen les dades",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Quan es pugen les dades a un proveïdor de serveis específic, els usuaris han de rebre informació sobre el lloc on el proveïdor de serveis específic emmagatzema les dades, durant quant de temps, sota quina jurisdicció opera el proveïdor de serveis específic i quina és la legislació aplicable.",
    "Freedom" : "Llibertat",
    "to choose a platform" : "per triar una plataforma",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Els usuaris sempre han de poder extreure les seves dades del servei en qualsevol moment, sense experimentar cap bloqueig per part del proveïdor. Per a garantir això, calen estàndards oberts per a formats i protocols.",
    "Learn more ↗" : "Més informació ↗",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Les vostres dades representen qui sou i poden ser objecte d’abús fàcilment. A Nextcloud creiem que teniu dret a decidir què passa amb les vostres dades. Nextcloud protegeix els vostres drets tal com es defineix al Manifest de dades de l'usuari!",
    "Somaliland" : "Somalilàndia",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emirats Àrabs Units",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua i Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albània",
    "Armenia" : "Armènia",
    "Angola" : "Angola",
    "Antarctica" : "Antàrtida",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Nord-americana",
    "Austria" : "Àustria",
    "Australia" : "Austràlia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Illes Åland",
    "Azerbaijan" : "Azerbaitjan",
    "Bosnia and Herzegovina" : "Bòsnia i Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bèlgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgària",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benín",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermudes",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolívia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius i Saba",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahames",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Illa Bouvet",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorússia",
    "Belize" : "Belize",
    "Canada" : "Canadà",
    "Cocos (Keeling) Islands" : "Illes Cocos (Keeling)",
    "Democratic Republic of the Congo" : "Repúplica Democràtica del Congo",
    "Central African Republic" : "República Centreafricana",
    "Congo" : "Congo",
    "Switzerland" : "Suïssa",
    "Cote d'Ivoire" : "Costa d'Ivori",
    "Cook Islands" : "Illes Cook",
    "Chile" : "Xile",
    "Cameroon" : "Camerun",
    "China" : "Xina",
    "Colombia" : "Colòmbia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cap Verd",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Illa Christmas",
    "Cyprus" : "Xipre",
    "Czech" : "República Txeca",
    "Germany" : "Alemanya",
    "Djibouti" : "Djibouti",
    "Denmark" : "Dinamarca",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Algèria",
    "Ecuador" : "Equador",
    "Estonia" : "Estònia",
    "Egypt" : "Egipte",
    "West Sahara" : "Sàhara Occidental",
    "Eritrea" : "Eritrea",
    "Spain" : "Espanya",
    "Ethiopia" : "Etiòpia",
    "Finland" : "Finlàndia",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Illes Malvines",
    "Micronesia" : "Estats Federats de la Micronèsia",
    "Faroe Islands" : "Illes Fèroe",
    "France" : "França",
    "Gabon" : "Gabon",
    "United Kingdom" : "Regne Unit",
    "Grenada" : "Grenada",
    "Georgia" : "Geòrgia",
    "French Guiana" : "Guaiana Francesa",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Groenlàndia",
    "Gambia" : "Gàmbia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadalupe",
    "Equatorial Guinea" : "Guinea Equatorial",
    "Greece" : "Grècia",
    "South Georgia and the South Sandwich Islands" : "Illes Geòrgia del Sud i Sandwich del Sud",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Illes Heard i McDonald",
    "Honduras" : "Hondures",
    "Croatia" : "Croàcia",
    "Haiti" : "Haití",
    "Hungary" : "Hongria",
    "Indonesia" : "Indonèsia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Illa de Man",
    "India" : "Índia",
    "British Indian Ocean Territory" : "Territori Britànic de l'Oceà Índic",
    "Iraq" : "Iraq",
    "Iran" : "Iran",
    "Iceland" : "Islàndia",
    "Italy" : "Itàlia",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordània",
    "Japan" : "Japó",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirguizistan",
    "Cambodia" : "Cambodja",
    "Kiribati" : "Kiribati",
    "Comores" : "Comores",
    "Saint Kitts and Nevis" : "Saint Kitts i Nevis",
    "North Korea" : "Corea del Nord",
    "South Korea" : "Corea del Sud",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Illes Caiman",
    "Kazakhstan" : "Kazakhstan",
    "Laos" : "Laos",
    "Lebanon" : "Líban",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Libèria",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lituània",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Letònia",
    "Libya" : "Líbia",
    "Morocco" : "Marroc",
    "Monaco" : "Mònaco",
    "Moldova" : "Moldàvia",
    "Montenegro" : "Montenegro",
    "Saint Martin" : "Saint-Martin",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Illes Marshall",
    "Macedonia" : "Macedònia",
    "Mali" : "Mali",
    "Myanmar" : "Birmània",
    "Mongolia" : "Mongòlia",
    "Macao" : "Macau",
    "Northern Mariana Islands" : "Illes Mariannes del Nord",
    "Mauritania" : "Mauritània",
    "Montserrat" : "Illa de Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Maurici",
    "Maldives" : "Maldives",
    "Malawi" : "Malawi",
    "Mexico" : "Mèxic",
    "Malaysia" : "Malàisia",
    "Mozambique" : "Moçambic",
    "Namibia" : "Namíbia",
    "New Caledonia" : "Nova Caledònia",
    "Niger" : "Níger",
    "Norfolk Island" : "Illa Norfolk",
    "Nigeria" : "Nigèria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Països Baixos",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nova Zelanda",
    "Oman" : "Oman",
    "Panama" : "Panamà",
    "Peru" : "Perú",
    "French Polynesia" : "Polinèsia Francesa",
    "Papua New Guinea" : "Papua Nova Guinea",
    "Philippines" : "Filipines",
    "Pakistan" : "Pakistan",
    "Poland" : "Polònia",
    "Saint Pierre and Miquelon" : "Sant Pere i Miquelon",
    "Pitcairn" : "Illes Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine" : "Palestina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguai",
    "Qatar" : "Qatar",
    "Réunion" : "La Reunió",
    "Romania" : "Romania",
    "Serbia" : "Sèrbia",
    "Russia" : "Rússia",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Aràbia Saudita",
    "Solomon Islands" : "Illes Salomó",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudan",
    "Sweden" : "Suècia",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Santa Helena, Ascensió i Tristan da Cunha",
    "Slovenia" : "Eslovènia",
    "Svalbard and Jan Mayen" : "Svalbard i Jan Mayen",
    "Slovakia" : "Eslovàquia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somàlia",
    "Suriname" : "Surinam",
    "South Sudan" : "Sudan del Sud",
    "Sao Tome and Principe" : "São Tomé i Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "Síria",
    "Swaziland" : "Swazilàndia",
    "Turks and Caicos Islands" : "Illes Turks i Caicos",
    "Chad" : "Txad",
    "Fr. S. Antarctic Lands" : "Terres Australs i Antàrtiques Franceses",
    "Togo" : "Togo",
    "Thailand" : "Tailàndia",
    "Tajikistan" : "Tadjikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor Oriental",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunísia",
    "Tonga" : "Tonga",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trinitat i Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzània",
    "Ukraine" : "Ucraïna",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Illes d'Ultramar Menors dels Estats Units",
    "United States" : "Estats Units",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Santa Seu",
    "Saint Vincent and the Grenadines" : "Saint Vincent i les Grenadines",
    "Venezuela" : "Veneçuela",
    "Virgin Islands (British)" : "Illes Verges Britàniques",
    "Virgin Islands (U.S.)" : "Illes Verges Nord-americanes",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis i Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Iemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sud-àfrica",
    "Zambia" : "Zàmbia",
    "Zimbabwe" : "Zimbabwe",
    "Adapt encryption" : "Adaptar el xifratge",
    "The admin has not selected the location of the server yet." : "L'administrador encara no ha seleccionat la ubicació del servidor.",
    "You don't have any shares with individual users." : "No teniu cap element compartit amb usuaris individuals.",
    "Your %s account" : "El vostre compte del %s",
    "Defining basic rights for people to control their own data in the internet age" : "Definició de drets bàsics perquè les persones puguin controlar les seves pròpies dades en l’era d'Internet",
    "People you shared with" : "Persones amb què heu compartit elements",
    "Read the privacy policy." : "Llegiu la política de privadesa."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.3.tgz: nextcloud/apps/privacy/l10n/ca.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privadesa",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "El centre de privadesa us mostra on s'emmagatzemen les vostres dades i qui pot accedir-hi, ja sigui perquè les vau compartir o perquè són usuaris administradors.",
    "Remove external {propertyName} admin" : "Elimina l'administrador extern {propertyName}",
    "Add external admin" : "Afegeix un administrador extern",
    "Name of external admin" : "Nom de l'administrador extern",
    "Adapt encryption" : "Adaptar el xifratge",
    "This server is using full-disk-encryption." : "Aquest servidor utilitza xifratge complet de disc.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "L'emmagatzematge de casa s'encripta mitjançant el {linkopen}xifratge del costat del servidor ↗{linkclose} amb una clau mestra. Significa que els administradors poden accedir als vostres fitxers, però no llegir-ne el contingut.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Els fitxers en ubicacions d'emmagatzematge extern poden estar xifrats mitjançant {linkopen}xifratge del servidor ↗{linkclose} amb una clau mestra en funció de la configuració.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "L'emmagatzematge de casa s'encripta mitjançant el {linkopen}xifratge del costat del servidor ↗{linkclose} amb una clau d'usuari individual. Significa que els administradors poden accedir als vostres fitxers, però no llegir-ne el contingut.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Els fitxers en ubicacions d'emmagatzematge extern poden estar xifrats mitjançant {linkopen}xifratge del servidor ↗{linkclose} amb una clau individual en funció de la configuració.",
    "Additionally, this server is protected with full-disk-encryption." : "A més, aquest servidor està protegit mitjançant xifratge complet del disc.",
    "This server is protected with full-disk-encryption." : "Aquest servidor està protegit mitjançant xifratge complet del disc.",
    "Your files are not protected by encryption." : "Els vostres fitxers no estan protegits per xifratge.",
    "Your data is located in:" : "Les vostres dades es troben a:",
    "The admin has not selected the location of the server yet." : "L'administrador encara no ha seleccionat la ubicació del servidor.",
    "Change data location" : "Canvia la ubicació de les dades",
    "Please select a region" : "Seleccioneu una regió",
    "You don't have any shares with individual users." : "No teniu cap element compartit amb usuaris individuals.",
    "Somaliland" : "Somalilàndia",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emirats Àrabs Units",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua i Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albània",
    "Armenia" : "Armènia",
    "Angola" : "Angola",
    "Antarctica" : "Antàrtida",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Nord-americana",
    "Austria" : "Àustria",
    "Australia" : "Austràlia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Illes Åland",
    "Azerbaijan" : "Azerbaitjan",
    "Bosnia and Herzegovina" : "Bòsnia i Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bèlgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgària",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benín",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermudes",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolívia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius i Saba",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahames",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Illa Bouvet",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorússia",
    "Belize" : "Belize",
    "Canada" : "Canadà",
    "Cocos (Keeling) Islands" : "Illes Cocos (Keeling)",
    "Democratic Republic of the Congo" : "Repúplica Democràtica del Congo",
    "Central African Republic" : "República Centreafricana",
    "Congo" : "Congo",
    "Switzerland" : "Suïssa",
    "Cote d'Ivoire" : "Costa d'Ivori",
    "Cook Islands" : "Illes Cook",
    "Chile" : "Xile",
    "Cameroon" : "Camerun",
    "China" : "Xina",
    "Colombia" : "Colòmbia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cap Verd",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Illa Christmas",
    "Cyprus" : "Xipre",
    "Czech" : "República Txeca",
    "Germany" : "Alemanya",
    "Djibouti" : "Djibouti",
    "Denmark" : "Dinamarca",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Algèria",
    "Ecuador" : "Equador",
    "Estonia" : "Estònia",
    "Egypt" : "Egipte",
    "West Sahara" : "Sàhara Occidental",
    "Eritrea" : "Eritrea",
    "Spain" : "Espanya",
    "Ethiopia" : "Etiòpia",
    "Finland" : "Finlàndia",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Illes Malvines",
    "Micronesia" : "Estats Federats de la Micronèsia",
    "Faroe Islands" : "Illes Fèroe",
    "France" : "França",
    "Gabon" : "Gabon",
    "United Kingdom" : "Regne Unit",
    "Grenada" : "Grenada",
    "Georgia" : "Geòrgia",
    "French Guiana" : "Guaiana Francesa",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Groenlàndia",
    "Gambia" : "Gàmbia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadalupe",
    "Equatorial Guinea" : "Guinea Equatorial",
    "Greece" : "Grècia",
    "South Georgia and the South Sandwich Islands" : "Illes Geòrgia del Sud i Sandwich del Sud",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Hondures",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Illes Heard i McDonald",
    "Croatia" : "Croàcia",
    "Haiti" : "Haití",
    "Hungary" : "Hongria",
    "Indonesia" : "Indonèsia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Illa de Man",
    "India" : "Índia",
    "British Indian Ocean Territory" : "Territori Britànic de l'Oceà Índic",
    "Iraq" : "Iraq",
    "Iran" : "Iran",
    "Iceland" : "Islàndia",
    "Italy" : "Itàlia",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordània",
    "Japan" : "Japó",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirguizistan",
    "Cambodia" : "Cambodja",
    "Kiribati" : "Kiribati",
    "Comores" : "Comores",
    "Saint Kitts and Nevis" : "Saint Kitts i Nevis",
    "North Korea" : "Corea del Nord",
    "South Korea" : "Corea del Sud",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Illes Caiman",
    "Kazakhstan" : "Kazakhstan",
    "Laos" : "Laos",
    "Lebanon" : "Líban",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Libèria",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lituània",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Letònia",
    "Libya" : "Líbia",
    "Morocco" : "Marroc",
    "Monaco" : "Mònaco",
    "Moldova" : "Moldàvia",
    "Montenegro" : "Montenegro",
    "Saint Martin" : "Saint-Martin",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Illes Marshall",
    "Macedonia" : "Macedònia",
    "Mali" : "Mali",
    "Myanmar" : "Birmània",
    "Mongolia" : "Mongòlia",
    "Macao" : "Macau",
    "Northern Mariana Islands" : "Illes Mariannes del Nord",
    "Mauritania" : "Mauritània",
    "Montserrat" : "Illa de Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Maurici",
    "Maldives" : "Maldives",
    "Malawi" : "Malawi",
    "Mexico" : "Mèxic",
    "Malaysia" : "Malàisia",
    "Mozambique" : "Moçambic",
    "Namibia" : "Namíbia",
    "New Caledonia" : "Nova Caledònia",
    "Niger" : "Níger",
    "Norfolk Island" : "Illa Norfolk",
    "Nigeria" : "Nigèria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Països Baixos",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nova Zelanda",
    "Oman" : "Oman",
    "Panama" : "Panamà",
    "Peru" : "Perú",
    "French Polynesia" : "Polinèsia Francesa",
    "Papua New Guinea" : "Papua Nova Guinea",
    "Philippines" : "Filipines",
    "Pakistan" : "Pakistan",
    "Poland" : "Polònia",
    "Saint Pierre and Miquelon" : "Sant Pere i Miquelon",
    "Pitcairn" : "Illes Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine" : "Palestina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguai",
    "Qatar" : "Qatar",
    "Réunion" : "La Reunió",
    "Romania" : "Romania",
    "Serbia" : "Sèrbia",
    "Russia" : "Rússia",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Aràbia Saudita",
    "Solomon Islands" : "Illes Salomó",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudan",
    "Sweden" : "Suècia",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Santa Helena, Ascensió i Tristan da Cunha",
    "Slovenia" : "Eslovènia",
    "Svalbard and Jan Mayen" : "Svalbard i Jan Mayen",
    "Slovakia" : "Eslovàquia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somàlia",
    "Suriname" : "Surinam",
    "South Sudan" : "Sudan del Sud",
    "Sao Tome and Principe" : "São Tomé i Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "Síria",
    "Swaziland" : "Swazilàndia",
    "Turks and Caicos Islands" : "Illes Turks i Caicos",
    "Chad" : "Txad",
    "Fr. S. Antarctic Lands" : "Terres Australs i Antàrtiques Franceses",
    "Togo" : "Togo",
    "Thailand" : "Tailàndia",
    "Tajikistan" : "Tadjikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor Oriental",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunísia",
    "Tonga" : "Tonga",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trinitat i Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzània",
    "Ukraine" : "Ucraïna",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Illes d'Ultramar Menors dels Estats Units",
    "United States" : "Estats Units",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Santa Seu",
    "Saint Vincent and the Grenadines" : "Saint Vincent i les Grenadines",
    "Venezuela" : "Veneçuela",
    "Virgin Islands (British)" : "Illes Verges Britàniques",
    "Virgin Islands (U.S.)" : "Illes Verges Nord-americanes",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis i Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Iemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sud-àfrica",
    "Zambia" : "Zàmbia",
    "Zimbabwe" : "Zimbabwe",
    "Your %s account" : "El vostre compte del %s",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Les vostres dades representen qui sou i poden ser objecte d’abús fàcilment. A Nextcloud creiem que teniu dret a decidir què passa amb les vostres dades. Nextcloud protegeix els vostres drets tal com es defineix al Manifest de dades de l'usuari!",
    "User Data Manifesto 2.0" : "Manifest de dades de l'usuari 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definició de drets bàsics perquè les persones puguin controlar les seves pròpies dades en l’era d'Internet",
    "Control" : "Control",
    "over user data access" : "sobre l’accés a les dades dels usuaris",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Les dades pujades de manera explícita i voluntària per part d'un usuari han d'estar sota el control definitiu de l'usuari. Els usuaris han de poder decidir a qui concedeixen accés directe a les seves dades i amb quins permisos i llicències es concedeix l'accés.",
    "Knowledge" : "Coneixement",
    "of how the data is stored" : "de com s'emmagatzemen les dades",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Quan es pugen les dades a un proveïdor de serveis específic, els usuaris han de rebre informació sobre el lloc on el proveïdor de serveis específic emmagatzema les dades, durant quant de temps, sota quina jurisdicció opera el proveïdor de serveis específic i quina és la legislació aplicable.",
    "Freedom" : "Llibertat",
    "to choose a platform" : "per triar una plataforma",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Els usuaris sempre han de poder extreure les seves dades del servei en qualsevol moment, sense experimentar cap bloqueig per part del proveïdor. Per a garantir això, calen estàndards oberts per a formats i protocols.",
    "Learn more ↗" : "Més informació ↗",
    "Where is your data?" : "On són les vostres dades?",
    "Who has access to your data?" : "Qui té accés a les vostres dades?",
    "Administrators" : "Administradors",
    "People you shared with" : "Persones amb què heu compartit elements",
    "Privacy policy" : "Política de privadesa",
    "Read the privacy policy." : "Llegiu la política de privadesa.",
    "Encryption" : "Xifratge",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key." : "L'emmagatzematge principal està xifrat mitjançant {linkopen}xifratge del servidor ↗{linkclose} amb una clau mestra.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key." : "L'emmagatzematge principal està xifrat mitjançant {linkopen}xifratge del servidor ↗{linkclose} amb una clau individual d'usuari."
},
"nplurals=2; plural=(n != 1);");
